#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Author: Michael Dvorak - specialis IT GmbH
# Version: 1.0 - 2021-12-31

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Age,
    Alternative,
    CascadingDropdown,
    Checkbox,
    Dictionary,
    DropdownChoice,
    Filesize,
    FixedValue,
    Integer,
    ListOf,
    ListOfStrings,
    RegExp,
    RegExpUnicode,
    TextAscii,
    TextUnicode,
    Transform,
    Tuple,
)
from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    RulespecGroupCheckParametersApplications,
    rulespec_registry,
)
    
def _parameter_valuespec_defender_threats():
    return Dictionary(
        title=_('Aknowledged threats'),
        elements=[
            ("id_patterns",
             ListOf(
                TextAscii(
                   title=_("DetectionID"),
                   size=60,
                ),
                title=_("Detection IDs which should be acknowledged. Format: A3F7AD35-C2F3-4C81-A7D7-4C67A1D10CC4"),
                help=
                _('<p>You can define multiple Detection IDs to be acknowledged! Threats about acknowledged Detection IDs will no longer be alarmed!</p>'),
                add_label=_("Add DetectionID"),
             )),   
        ],
    )
    
rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="spit_defender_threats",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_defender_threats,
        title=lambda: _("Defender acknowledged threats"),
    ))
