﻿#####################################################################################################################
#  ScriptName: spit_defender_threats.ps1
#
#  Description:
#  This plugin gets found threats of Windows Defender and System Center Endpoint Protection. Make sure
#  that Windows Defender or System Center Endpoint Protection is installed on the machine!
#
#  Author: Dvorak Michael - specialis IT GmbH
#####################################################################################################################
#  Version History
#  1.0 - 2021-12-29 - initial Release
#####################################################################################################################

# get the OS version
$osVersion = [Environment]::OSVersion.Version.Major

$cmdExists = $false

# check if OS version is Win8/WinServer2012
if ($osVersion -eq 6) {

    if (Test-Path -Path "C:\Program Files\Microsoft Security Client\MpProvider\MpProvider.psd1") {

        Import-Module "C:\Program Files\Microsoft Security Client\MpProvider\MpProvider.psd1" -ErrorAction Ignore
        
        $cmdExists = Get-Command Get-MProtThreatDetection -ErrorAction SilentlyContinue

        if ($cmdExists) { $currThreats = Get-MProtThreatDetection }
    }
    
} else {
    
    $cmdExists = Get-Command Get-MpThreatDetection -ErrorAction SilentlyContinue
    
    if ($cmdExists) { $currThreats = Get-MpThreatDetection }     
}

if (!$cmdExists) { exit }

Function formatValue($value) {

    if ($value -eq $null) { $value = " "}
    return ($value.ToString()).Replace(' ','-')
}

Write-Output "<<<spit_defender_threats>>>"

# Check if the object is valid - if it's null, it's ok - because then there are no threats
if (!$currThreats) {

    $values = @($osVersion)
    $values += "{no_threats_found}"
    $values += "-"
    $values += "-"       
    $values += "-"     
    $values += "-"
    $values += "-"    

    [System.String]::Join(" ",$values)

} else {

    # Iterate through the detections
    $currThreats | ForEach {
    
        if ($_.DomainUser) {

            $domUser = $_.DomainUser

        } else {

            $domUser = "-\-"

        }

        $values = @($osVersion)
        $values += $_.DetectionID -replace '[{}]',''
        $values += $domUser
        $values += $_.InitialDetectionTime       
        $values += ($_.ProcessName).replace(' ','_') 
        $values += (($_.Resources)[0] -replace 'file:_','').Replace(' ','%20')

        [System.String]::Join(" ",$values)
    }
}

